%The function taks electric field data from a rod-plane gap as input with
%known applied voltage of 15kV and calculates the inception voltage

function U = inception(s_original)
%s_original is a vector with position [m] in the first column and 
%electric field strength [V/m] in the second column

    %A while loop is used to increase the voltage until there are
    %enough electrons
    U_next = 100; %[V]
    U_prev = U_next;
    electrons = log(10^8);
    done = 0;
    while ~done
        %Scaling the data to a new voltage
        s = skaler(s_original, 15000, U_next);

        %Calculates the integral of the streamer inception criterion
        I = integrate_criterion(s);

        %Checking whether there are enough electrons. If not, voltage
        %is increaseed
        if I>electrons
            done = 1;
        elseif U_prev > 8000000
            disp('Error. Task is aborted.');
            U = U_prev;
            return
        else
            U_prev = U_next;
            U_next = U_prev*2;
            done = 0;
        end
    end
    
    %A while loop is used to find the inception voltage by binary search
    U_upper = U_next;
    U_lower = U_prev;
    done = 0;
    while ~done
        U_test = (U_upper + U_lower)/2;
        %Scaling the data to a new voltage
        s = skaler(s_original, 15000, U_test);

        %Calculates the integral of the streamer inception criterion
        I = integrate_criterion(s);

        %Checking whether the test voltage interval has become infinitely
        %narrow, meaning that the inception voltage has been determined
        if floor(U_upper) == floor(U_lower)
            done = 1;
        end

        %Checking whether there are enough electrons
        if I>electrons
            U_upper = U_test;
        else
            U_lower = U_test;
        end
    end
    
    U = U_test;
end
